@@ -4,6 +4,7 @@ from django import forms
 from hyperadmin.apirequests import Namespace
 from hyperadmin.resources.crud import CRUDResource
 from hyperadmin.resources.models.indexes import ModelIndex, InlineIndex
+from hyperadmin.resources.models.endpoints import ListEndpoint, CreateEndpoint, DetailEndpoint, DeleteEndpoint
 from hyperadmin.resources.models.endpoints import InlineListEndpoint, InlineCreateEndpoint, InlineDetailEndpoint, InlineDeleteEndpoint
 
 
@@ -42,14 +43,9 @@ class BaseModelResource(CRUDResource):
     
     def get_app_name(self):
         return self.opts.app_label
-    app_name = property(get_app_name)
     
     def get_resource_name(self):
         return self.opts.module_name
-    resource_name = property(get_resource_name)
-    
-    def get_prompt(self):
-        return self.resource_name
     
     def get_primary_query(self, **kwargs):
         return self.get_queryset()
@@ -171,6 +167,11 @@ class BaseModelResource(CRUDResource):
         return AdminForm
 
 class ModelResource(BaseModelResource):
+    list_endpoint_class = ListEndpoint
+    create_endpoint_class = CreateEndpoint
+    detail_endpoint_class = DetailEndpoint
+    delete_endpoint_class = DeleteEndpoint
+    
     def post_register(self):
         super(ModelResource, self).post_register()
         self.initialize_inlines()
@@ -187,16 +188,12 @@ class ModelResource(BaseModelResource):
     def register_inline(self, inline_cls):
         self.inline_instances.append(inline_cls(parent=self, api_request=self.api_request))
     
-    def get_view_endpoints(self):
-        from hyperadmin.resources.models.endpoints import ListEndpoint, CreateEndpoint, DetailEndpoint, DeleteEndpoint
-        endpoints = super(CRUDResource, self).get_view_endpoints()
-        endpoints.extend([
-            (ListEndpoint, {'index_name':'filter'}),
-            (CreateEndpoint, {}),
-            (DetailEndpoint, {}),
-            (DeleteEndpoint, {}),
-        ])
-        return endpoints
+    def register_endpoint(self, endpoint_cls, **kwargs):
+        #TODO find a better strategy for injecting the index name for list endpoints
+        #perhaps list_endpoint could be a tuple of class and kwargs
+        if endpoint_cls == self.list_endpoint_class:
+            kwargs.setdefault('index_name', 'filter')
+        return super(ModelResource, self).register_endpoint(endpoint_cls, **kwargs)
     
     def get_urls(self):
         urlpatterns = super(ModelResource, self).get_urls()
@@ -226,6 +223,11 @@ class InlineModelResource(BaseModelResource):
     fk_name = None
     rel_name = None
     
+    list_endpoint_class = InlineListEndpoint
+    create_endpoint_class = InlineCreateEndpoint
+    detail_endpoint_class = InlineDetailEndpoint
+    delete_endpoint_class = InlineDeleteEndpoint
+    
     def __init__(self, parent, **kwargs):
         kwargs['site'] = parent.site
         kwargs['resource_adaptor'] = self.model
@@ -257,16 +259,6 @@ class InlineModelResource(BaseModelResource):
     def get_base_url_name(self):
         return '%s%s' % (self._parent.get_base_url_name(), self.rel_name)
     
-    def get_view_endpoints(self):
-        endpoints = super(CRUDResource, self).get_view_endpoints()
-        endpoints.extend([
-            (InlineListEndpoint, {}),
-            (InlineCreateEndpoint, {}),
-            (InlineDetailEndpoint, {}),
-            (InlineDeleteEndpoint, {}),
-        ])
-        return endpoints
-    
     def get_item_url(self, item):
         return self.link_prototypes['update'].get_url(item=item)
     
