@@ -6,7 +6,7 @@ from hyperadmin.links import Link
 from hyperadmin.resources.crud import CRUDResource
 from hyperadmin.resources.storages.forms import UploadForm, UploadLinkForm
 from hyperadmin.resources.storages.indexes import StorageIndex
-from hyperadmin.resources.storages.endpoints import ListEndpoint, CreateEndpoint, CreateUploadEndpoint, DetailEndpoint, DeleteEndpoint, BoundFile
+from hyperadmin.resources.storages.endpoints import ListEndpoint, CreateUploadEndpoint, BoundFile
 
 
 class StorageQuery(object):
@@ -37,30 +37,15 @@ class StorageQuery(object):
 
 class StorageResource(CRUDResource):
     #resource_adaptor = storage object
-    #paginator_class = StoragePaginator
     form_class = UploadForm
     upload_link_form_class = UploadLinkForm
+    list_endpoint_class = ListEndpoint
+    create_upload_endpoint_class = CreateUploadEndpoint
     
     def __init__(self, **kwargs):
         kwargs.setdefault('app_name', '-storages')
         super(StorageResource, self).__init__(**kwargs)
     
-    def get_app_name(self):
-        return self._app_name
-    
-    def set_app_name(self, name):
-        self._app_name = name
-    
-    app_name = property(get_app_name, set_app_name)
-    
-    def get_resource_name(self):
-        return self._resource_name
-    
-    def set_resource_name(self, name):
-        self._resource_name = name
-    
-    resource_name = property(get_resource_name, set_resource_name)
-    
     def get_storage(self):
         return self.resource_adaptor
     storage = property(get_storage)
@@ -69,13 +54,9 @@ class StorageResource(CRUDResource):
         return self.upload_link_form_class
     
     def get_view_endpoints(self):
-        endpoints = super(CRUDResource, self).get_view_endpoints()
+        endpoints = super(StorageResource, self).get_view_endpoints()
         endpoints.extend([
-            (ListEndpoint, {}),
-            (CreateEndpoint, {}),
-            (CreateUploadEndpoint, {}),
-            (DetailEndpoint, {}),
-            (DeleteEndpoint, {}),
+            (self.create_upload_endpoint_class, {}),
         ])
         return endpoints
     
