@@ -36,6 +36,7 @@ class EndpointViewMixin(ConditionalAccessMixin):
         """
         Takes a django request object and builds an APIRequest object
         Calls dispatch_api with the api request
+        :rtype: HttpResponse
         """
         assert not self.api_request
         api_request = self.site.create_apirequest(request=request, url_args=args, url_kwargs=kwargs)
@@ -43,6 +44,18 @@ class EndpointViewMixin(ConditionalAccessMixin):
         return endpoint.dispatch_api(api_request)
     
     def dispatch_api(self, api_request):
+        '''
+        Execute the api request
+        :rtype: HttpResponse
+        '''
+        response = self.generate_api_response(api_request)
+        return self.normalize_response(response)
+    
+    def generate_api_response(self, api_request):
+        '''
+        Returns the result of executing a link
+        :rtype: Link or HttpResponse
+        '''
         if api_request.method.lower() in self.http_method_names:
             handler = getattr(self, api_request.method.lower(), self.handle_link_submission)
         else:
@@ -59,15 +72,21 @@ class EndpointViewMixin(ConditionalAccessMixin):
         
         permission_response = self.api_permission_check(api_request)
         if permission_response is not None:
-            response_or_link = permission_response
+            return permission_response
         else:
-            response_or_link = handler(api_request)
+            return handler(api_request)
+    
+    def normalize_response(self, response_or_link):
+        '''
+        Converts a link response to an HttpResponse
+        :rtype: HttpResponse
+        '''
         if isinstance(response_or_link, Link):
             #TODO TemplateResponse with a link
             response = self.generate_response(response_or_link)
         else:
             response = response_or_link
-        if not self.cacheable:
+        if not self.cacheable and isinstance(response, http.HttpResponse):
             add_never_cache_headers(response)
         return response
     
@@ -78,6 +97,12 @@ class EndpointViewMixin(ConditionalAccessMixin):
         return {}
     
     def handle_link_submission(self, api_request):
+        """
+        Looks up the appropriate link for the HTTP Method and returns 
+        the link.
+        If Method is in `self.submit_methods` then return the result of
+        submitting the link.
+        """
         method = api_request.method.upper()
         proto = self.get_link_prototype_for_method(method)
         
